@@ -8,7 +8,7 @@ from django.contrib.admin.filters import (AllValuesFieldListFilter,
 from django.db.models.fields.related import ForeignObjectRel
 from django.db.models.query_utils import Q
 from django.utils.encoding import smart_str
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 
 
 def get_attr(obj, attr, default=None):
